@@ -5,43 +5,52 @@
 from functools import wraps
 from textwrap import fill
 from contextlib import redirect_stdout
-import io, inspect
+import io, inspect, os
 
 
 def prex(details, exc_tr, fc_name):
     """Printing Exception"""
 
-    print(f"Filename caller: {details[0].filename.upper()}\n")
+    print(f"\nFilename caller: {details[0].filename.upper()}\n")
     print(f"ERROR - <{fc_name}>:")
     print(f"{'-' * 70}", end="\n")
     print("Start at:\n")
 
+    filenm = details[0].filename
     for detail in details:
-        cc = fill(
-            "".join(detail.code_context).strip(),
-            initial_indent=" " * 4,
-            subsequent_indent=" " * 4,
-        )
-        print(f"line {detail.lineno} in {detail.function}:\n" f"{cc}\n")
-        del detail, cc
+        if "excptr.py" not in detail.filename:
+            if filenm != detail.filename:
+                print(f"Filename: {detail.filename.upper()}\n")
+            cc = fill(
+                "".join(detail.code_context).strip(),
+                initial_indent=" " * 4,
+                subsequent_indent=" " * 4,
+            )
+            print(f"line {detail.lineno} in {detail.function}:\n" f"{cc}\n")
+            del cc
+        del detail
 
-    tot = f"<- Exception raise: {exc_tr.__class__.__name__} ->"
+    tot = f">>>- Exception raise: {exc_tr.__class__.__name__} ->"
     print("~" * len(tot))
     print(tot)
     print("~" * len(tot) + "\n")
 
     allextr = inspect.getinnerframes(exc_tr.__traceback__)[1:]
     for extr in allextr:
-        cc = fill(
-            "".join(extr.code_context).strip(),
-            initial_indent=" " * 4,
-            subsequent_indent=" " * 4,
-        )
-        print(f"line {extr.lineno} in {extr.function}:\n" f"{cc}\n")
-        del extr, cc
+        if "excptr.py" not in extr.filename:
+            if filenm != extr.filename:
+                print(f"Filename: {extr.filename.upper()}\n")
+            cc = fill(
+                "".join(extr.code_context).strip(),
+                initial_indent=" " * 4,
+                subsequent_indent=" " * 4,
+            )
+            print(f"line {extr.lineno} in {extr.function}:\n" f"{cc}\n")
+            del cc
+        del extr
     print(f"{exc_tr.__class__.__name__}: {exc_tr.args[0]}")
     print(f"{'-' * 70}", end="\n")
-    del tot, allextr, details, exc_tr, fc_name
+    del tot, allextr, filenm, details, exc_tr, fc_name
 
 
 def crtk(v: str):
@@ -76,7 +85,7 @@ def crtk(v: str):
         nonlocal scnd
         scnd += scnd if scnd < 20000 else 5000
         match scnd:
-            case sec if sec <= 35000:
+            case sec if sec <= 25000:
                 ans = msg.askyesno(
                     "Viewing",
                     f"Still viewing for another {scnd//1000} seconds?",
@@ -86,7 +95,7 @@ def crtk(v: str):
                     root.after(scnd, viewing)
                 else:
                     root.destroy()
-            case sec if sec > 35000:
+            case sec if sec > 25000:
                 msg.showinfo(
                     "Viewing", "Viewing cannot exceed more than 1 minute!", parent=root
                 )
@@ -97,15 +106,26 @@ def crtk(v: str):
     del root, text, scr, scnd
 
 
-def excp(m: int = -1):
+def ckrflex(filenm: str) -> bool:
+    if os.path.exists(filenm):
+        with open(filenm) as rd:
+            if rd.readline():
+                return False
+            else:
+                return True
+    else:
+        return True
+
+
+def excp(m: int = -1, filenm: str = None):
     """Decorator for function"""
 
     match m:
         case m if not isinstance(m, int):
             raise ValueError(f'm = "{m}" Need to be int instead!')
-        case m if m not in [-1, 0, 1]:
+        case m if m not in [-1, 0, 1, 2]:
             raise ValueError(
-                f'm = "{m}" Need to be either one of them, [-1 or 0 or 1]!'
+                f'm = "{m}" Need to be either one of them, [-1 or 0 or 1 or 2]!'
             )
 
     def ckerr(f):
@@ -130,6 +150,29 @@ def excp(m: int = -1):
                             prex(details, e, f.__name__)
                         crtk(v.getvalue())
                         v.flush()
+                    case 2:
+                        if filenm:
+                            from datetime import datetime as dt
+
+                            v = io.StringIO()
+                            with redirect_stdout(v):
+                                prex(details, e, f.__name__)
+                            wrm = (
+                                str(dt.today()).rpartition(".")[0]
+                                + ": TRACING EXCEPTION\n"
+                                if ckrflex(filenm)
+                                else "\n"
+                                + str(dt.today()).rpartition(".")[0]
+                                + ": TRACING EXCEPTION\n"
+                            )
+                            with open(filenm, "a") as log:
+                                log.write(wrm)
+                                log.write(v.getvalue())
+                            v.flush()
+                            del v, wrm
+                        else:
+                            raise
+
                 del details, e
 
         return trac
@@ -137,15 +180,15 @@ def excp(m: int = -1):
     return ckerr
 
 
-def excpcls(m: int = -1):
+def excpcls(m: int = -1, filenm: str = None):
     """Decorator for class (for functions only)"""
 
     match m:
         case m if not isinstance(m, int):
             raise ValueError(f'm = "{m}" Need to be int instead!')
-        case m if m not in [-1, 0, 1]:
+        case m if m not in [-1, 0, 1, 2]:
             raise ValueError(
-                f'm = "{m}" Need to be either one of them, [-1 or 0 or 1]!'
+                f'm = "{m}" Need to be either one of them, [-1 or 0 or 1 or 2]!'
             )
 
     def catchcall(cls):
@@ -156,7 +199,7 @@ def excpcls(m: int = -1):
             case _:
                 for name, obj in vars(cls).items():
                     if inspect.isfunction(obj):
-                        setattr(cls, name, excp(ckb)(obj))
+                        setattr(cls, name, excp(ckb, filenm)(obj))
 
         return cls
 
